<?php
/* $Id: bulgarian-koi8-r.inc.php,v 2.79 2005/08/18 10:09:13 lem9 Exp $ */

/**
 * Translated by Stanislav Yordanov <stanprog at stanprog.com>
 * Based on translation made by Georgi Georgiev <chutz at chubaka.homeip.net>
 */

$charset = 'koi8-r';
$text_dir = 'ltr';
$left_font_family = 'sans-serif';
$right_font_family = 'sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('', '', '', '', '', '', '');

$day_of_week = array('', '', '', '', '', '', '');
$month = array('', '', '', '', '', '', '', '', '', '', '', '');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%e %B %Y  %H:%M';

$timespanfmt = '%s , %s , %s   %s ';

$strAbortedClients = '';
$strAbsolutePathToDocSqlDir = '        docSQL ';
$strAccessDeniedExplanation = 'phpMyAdmin       MySQL ,    .    ,      config.inc.php     ,          MySQL .';
$strAccessDenied = ' ';
$strAction = '';
$strAddAutoIncrement = '  AUTO_INCREMENT';
$strAddConstraints = '  ';
$strAddDeleteColumn = '/   ';
$strAddDeleteRow = '/   ';
$strAddDropDatabase = '  DROP DATABASE';
$strAddedColumnComment = '   ';
$strAddedColumnRelation = '   ';
$strAddFields = '   %s ()';
$strAddHeaderComment = '     (\\n  )';
$strAddIfNotExists = '  IF NOT EXISTS'; 
$strAddIntoComments = '  ';
$strAddNewField = '   ';
$strAddPrivilegesOnDb = '       ';
$strAddPrivilegesOnTbl = '     ';
$strAddSearchConditions = '    (  "where" ):';
$strAddToIndex = ' &nbsp;%s&nbsp;() ()   ';
$strAddUserMessage = '   .';
$strAddUser = '   .';
$strAdministration = '';
$strAffectedRows = ' :';
$strAfterInsertBack = ' ';
$strAfterInsertNewInsert = '   ';
$strAfterInsertNext = '   ';
$strAfterInsertSame = '   ';
$strAfter = ' %s';
$strAll = '';
$strAllTableSameWidth = '        ?';
$strAlterOrderBy = '   ';
$strAnalyzeTable = '  ';
$strAnd = '';
$strAnIndex = '    %s';
$strAny = '';
$strAnyHost = ' ';
$strAnyUser = ' ';
$strApproximateCount = '    .  FAQ 3.11';
$strAPrimaryKey = 'ee     ';
$strArabic = '';
$strArmenian = '';
$strAscending = '';
$strAtBeginningOfTable = '   ';
$strAtEndOfTable = '   ';
$strAttr = '';
$strAutodetect = ' ';
$strAutomaticLayout = ' ';

$strBack = '';
$strBaltic = '';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = '  ';
$strBinaryDoNotEdit = '  -    ';
$strBookmarkAllUsers = '       bookmark';
$strBookmarkDeleted = 'Bookmark  .';
$strBookmarkLabel = '';
$strBookmarkOptions = 'Bookmark ';
$strBookmarkQuery = '  SQL ';
$strBookmarkThis = '  SQL ';
$strBookmarkView = ' ';
$strBrowseForeignValues = '  (foreign) ';
$strBrowse = '';
$strBulgarian = '';
$strBzError = 'phpMyAdmin     (dump)    Bz2      PHP.        <code>$cfg[\'BZipDump\']</code>       phpMyAdmin  <code>FALSE</code>.        Bz2 ,      -   PHP.   %s   .';
$strBzip = '"bzip-"';

$strCalendar = ''; 
$strCannotLogin = '      MySQL ';
$strCantLoad = '     %s,<br />    PHP';
$strCantLoadRecodeIconv = '     iconv  recode        (charset),  PHP ,              (charset)  phpMyAdmin.';
$strCantRenameIdxToPrimary = '      PRIMARY!';
$strCantUseRecodeIconv = '      iconv  libiconv  recode_string       .    PHP.';
$strCardinality = '';
$strCarriage = '    : \\r';
$strCaseInsensitive = '  ';
$strCaseSensitive = '  ';
$strCentralEuropean = ' ';
$strChangeCopyModeCopy = '...   .';
$strChangeCopyModeDeleteAndReload = ' ...             .';
$strChangeCopyModeJustDelete = ' ...       .';
$strChangeCopyMode = '       ...';
$strChangeCopyModeRevoke = ' ...           .';
$strChangeCopyUser = '    /   ';
$strChangeDisplay = '   ';
$strChange = '';
$strChangePassword = '  ';
$strCharsetOfFile = '    :';
$strCharsetsAndCollations = '    ';
$strCharsets = '  ';
$strCharset = '  ';
$strCheckAll = '  ';
$strCheckPrivsLong = '      &quot;%s&quot;.';
$strCheckPrivs = '  ';
$strCheckTable = '  ';
$strChoosePage = '    ';
$strColComFeat = '    ';
$strCollation = '';
$strColumnNames = '  ';
$strColumnPrivileges = '   ';
$strCommand = '';
$strCommentsForTable = '  ';
$strComments = '';
$strCompatibleHashing = 'MySQL&nbsp;4.0 ';
$strCompleteInserts = ' INSERT-';
$strCompression = '';
$strConfigFileError = 'phpMyAdmin       !<br />      PHP           .<br />        -       PHP .  -   ,       .<br />    ,   .';
$strConfigureTableCoord = '     %s';
$strConnectionError = '     :  .';
$strConnections = '';
$strConstraintsForDumped = '   ';
$strConstraintsForTable = '  ';
$strCookiesRequired = '    "Cookies".';
$strCopyTableOK = ' %s    %s.';
$strCopyTableSameNames = '        !';
$strCopyTable = '   (  <b>.</b>):';
$strCouldNotKill = 'phpMyAdmin      %s.     .';
$strCreateIndex = '    &nbsp;%s&nbsp;';
$strCreateIndexTopic = '  ';
$strCreateNewDatabase = '   ';
$strCreateNewTable = '     %s';
$strCreate = '';
$strCreatePage = '  ';
$strCreatePdfFeat = '  PDF-';
$strCreationDates = '//  ';
$strCriteria = '';
$strCroatian = '';
$strCSVOptions = 'CSV ';
$strCyrillic = '';
$strCzech = '';
$strCzechSlovak = '';

$strDanish = '';
$strDatabase = '';
$strDatabaseEmpty = '      !';
$strDatabaseExportOptions = '      ';
$strDatabaseHasBeenDropped = '  %s  .';
$strDatabaseNoTable = '    !';
$strDatabasesDropped = '%s      .';
$strDatabasesStatsDisable = ' ';
$strDatabasesStatsEnable = ' ';
$strDatabasesStatsHeavyTraffic = ':                  MySQL .';
$strDatabasesStats = '    ';
$strDatabases = '  ';
$strDataDict = '  ';
$strData = '';
$strDataOnly = ' ';
$strDBComment = '    : ';
$strDBGContextID = ' ID';
$strDBGContext = '';
$strDBGHits = '';
$strDBGLine = '';
$strDBGMaxTimeMs = '. , ms';
$strDBGMinTimeMs = '. , ms';
$strDBGModule = '';
$strDBGTimePerHitMs = '/, ms';
$strDBGTotalTimeMs = ' , ms';
$strDbPrivileges = '     ';
$strDBRename = '     '; 
$strDbSpecific = '    ';
$strDefaultEngine = '%s         MySQL .';
$strDefaultValueHelp = '   ,     ,     ,   : a';
$strDefault = ' ';
$strDefragment = '  ';
$strDelayedInserts = '   ';
$strDeleteAndFlushDescr = '  - ,         .';
$strDeleteAndFlush = '        .';
$strDeleted = '  ';
$strDeletedRows = ' :';
$strDelete = '';
$strDeleting = '  %s';
$strDelOld = '         .      ?';
$strDescending = '';
$strDescription = '';
$strDictionary = '';
$strDisabled = '';
$strDisableForeignChecks = '     ';
$strDisplayFeat = ' ';
$strDisplayOrder = ' :';
$strDisplayPDF = ' PDF ';
$strDoAQuery = ' "  " (   : "%")';
$strDocu = '';
$strDoYouReally = '     ';
$strDropDatabaseStrongWarning = '      !';
$strDrop = '';
$strDropSelectedDatabases = '     ';
$strDropUsersDb = '           .';
$strDumpingData = ' ()    ';
$strDumpSaved = '()     %s.';
$strDumpXRows = '- %s     %s.';
$strDynamic = '';

$strEdit = '';
$strEditPDFPages = '  PDF ';
$strEditPrivileges = '  ';
$strEffective = '';
$strEmpty = '';
$strEmptyResultSet = 'MySQL    (..  ).';
$strEnabled = '';
$strEncloseInTransaction = '    ';
$strEndCut = 'END CUT';
$strEnd = '';
$strEndRaw = 'END RAW';
$strEngineAvailable = '%s     MySQL .';
$strEngineDisabled = '%s     MySQL .';
$strEngines = '';
$strEngineUnsupported = ' MySQL       %s.';
$strEnglish = '';
$strEnglishPrivileges = ' :     MySQL    . ';
$strError = '';
$strEstonian = '';
$strExcelEdition = 'Excel- ';
$strExcelOptions = '  Excel';
$strExecuteBookmarked = '   SQL-';
$strExplain = 'Explain SQL';
$strExport = '';
$strExtendedInserts = ' INSERT-';
$strExtra = '';

$strFailedAttempts = '  ';
$strFieldHasBeenDropped = ' %s  ';
$strFieldsEmpty = '     ! ';
$strFieldsEnclosedBy = '   ';
$strFieldsEscapedBy = '   ';
$strFieldsTerminatedBy = '  ';
$strFields = '';
$strField = '';
$strFileAlreadyExists = ' %s    ,         .';
$strFileCouldNotBeRead = '     ';
$strFileNameTemplateHelp = ' __DB__      , __TABLE__        %sstrftime%s      ,      .      .';
$strFileNameTemplateRemember = '  ';
$strFileNameTemplate = '   ';
$strFixed = '';
$strFlushPrivilegesNote = ': phpMyAdmin          MySQL.                     .   ,   %s %s   .';
$strFlushTable = '     ("FLUSH")';
$strFormat = '';
$strFormEmpty = '     !';
$strFullText = ' ';
$strFunction = '';

$strGenBy = ' ';
$strGeneralRelationFeat = '   ';
$strGenTime = '  ';
$strGeorgian = '';
$strGerman = '';
$strGlobal = '';
$strGlobalPrivileges = ' ';
$strGlobalValue = ' ';
$strGo = '';
$strGrantOption = '';
$strGreek = '';
$strGzip = '"gzip-"';

$strHasBeenAltered = ' .';
$strHasBeenCreated = ' .';
$strHaveToShow = '       ';
$strHebrew = '';
$strHexForBinary = '      ';
$strHome = '';
$strHomepageOfficial = '    phpMyAdmin ';
$strHostEmpty = '    !';
$strHost = '';
$strHungarian = '';

$strIcelandic = '';
$strId = 'ID';
$strIdxFulltext = '';
$strIfYouWish = '        ,       .';
$strIgnore = '';
$strIgnoreInserts = '  INSERT IGNORE';
$strIgnoringFile = '   %s';
$strImportDocSQL = ' docSQL ';
$strImportFiles = '  ';
$strImportFinished = ' ';
$strIndexes = '';
$strIndexHasBeenDropped = ' %s  ';
$strIndexName = '  &nbsp;:';
$strIndex = '';
$strIndexType = '  &nbsp;:';
$strInnodbStat = 'InnoDB ';
$strInsecureMySQL = '     (root  ),       MySQL  .  MySQL             . T      .';
$strInsertAsNewRow = '   ';
$strInsertedRowId = ' ID  :';
$strInsertedRows = ' :';
$strInsertNewRow = '   ';
$strInsert = '';
$strInsertTextfiles = '     ';
$strInstructions = '';
$strInternalNotNecessary = '*          InnoDB.';
$strInternalRelations = ' ';
$strInUse = '';
$strInvalidColumnCount = '      -  .';
$strInvalidFieldAddCount = '     .';
$strInvalidFieldCount = '      .';
$strInvalidRowNumber = '%d      .';

$strJapanese = '';
$strJumpToDB = '     &quot;%s&quot;.';
$strJustDeleteDescr = '&quot;&quot;        ,     .';
$strJustDelete = '      .';

$strKeepPass = '    ';
$strKeyname = '  ';
$strKill = '';
$strKorean = '';

$strLandscape = '';
$strLatexCaption = '  ';
$strLatexContent = '   __TABLE__';
$strLatexContinuedCaption = '    ';
$strLatexContinued = '()';
$strLatexIncludeCaption = '    ';
$strLatexLabel = '  ';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX ';
$strLatexStructure = '   __TABLE__';
$strLatvian = '';
$strLengthSet = '/*';
$strLimitNumRows = '  ';
$strLineFeed = '    : \\n';
$strLinesTerminatedBy = '  ';
$strLinkNotFound = '   ';
$strLinksTo = ' ';
$strLithuanian = '';
$strLoadExplanation = '     ,         .';
$strLoadMethod = 'LOAD ';
$strLocalhost = '';
$strLocationTextfile = '   ';
$strLoginInformation = '  ';
$strLogin = '';
$strLogout = '  ';
$strLogPassword = ':';
$strLogServer = '';
$strLogUsername = ':';

$strMaximumSize = ' : %s%s';
$strMIME_available_mime = ' MIME-';
$strMIME_available_transform = ' ';
$strMIME_description = '';
$strMIME_MIMEtype = 'MIME-';
$strMIME_nodescription = '    .<br />         %s.';
$strMIME_transformation = ' ';
$strMIME_transformation_note = '         MIME-type    %s  %s';
$strMIME_transformation_options_note = '          : \'a\',\'b\',\'c\'...<br />       ("\")    ("\'")   ,        ( \'\\\\xyz\'  \'a\\\'b\').';
$strMIME_transformation_options = '  ';
$strMIMETypesForTable = 'MIME   ';
$strMIME_without = 'MIME-types          ';
$strModifications = '  ';
$strModifyIndexTopic = '  ';
$strModify = '';
$strMoreStatusVars = '   ';
$strMoveTable = '    (  <b>.</b>):';
$strMoveTableOK = ' %s    %s.';
$strMoveTableSameNames = '        !';
$strMultilingual = '';
$strMustSelectFile = '     .';
$strMyISAMMaxExtraSortFileSize = '        ';
$strMyISAMRecoverOptions = '   ';
$strMyISAMSortBufferSize = '    ';
$strMySQLCharset = '    MySQL';
$strMySQLConnectionCollation = '  MySQL';
$strMySQLReloaded = 'MySQL  .';
$strMySQLSaid = 'MySQL : ';
$strMySQLServerProcess = 'MySQL %pma_s1%    %pma_s2%  %pma_s3%';
$strMySQLShowProcess = 'MySQL ';
$strMySQLShowStatus = '    MySQL ';
$strMySQLShowVars = '   MySQL';

$strName = '';
$strNeedPrimaryKey = '    (primary key)   .';
$strNext = '';
$strNoDatabases = '   ';
$strNoDatabasesSelected = '    .';
$strNoDescription = ' ';
$strNoDetailsForEngine = '         .';
$strNoDropDatabases = '"DROP DATABASE"   .';
$strNoExplain = ' Explain SQL';
$strNoFrames = 'phpMyAdmin      ,   <b>frames</b>.';
$strNoIndexPartsDefined = '     !';
$strNoIndex = '   !';
$strNoModification = ' ';
$strNone = '';
$strNo = '';
$strNoOptions = '   ';
$strNoPassword = ' ';
$strNoPermission = '        %s.';
$strNoPhp = ' PHP ';
$strNoPrivileges = ' ';
$strNoQuery = ' SQL !';
$strNoRights = '           !';
$strNoRowsSelected = '  ';
$strNoSpace = '       %s.';
$strNoTablesFound = '     .';
$strNotNumber = '   !';
$strNotOK = '  OK';
$strNotSet = '  <b>%s</b>         %s';
$strNoUsersFound = ' ().';
$strNoValidateSQL = ' Validate SQL';
$strNull = '';
$strNumSearchResultsInTable = '%s ()   <i>%s</i>';
$strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ()';
$strNumTables = '';

$strOftenQuotation = ' .  ,    char  varchar    .';
$strOK = 'OK';
$strOperations = '';
$strOperator = '';
$strOptimizeTable = '  ';
$strOptionalControls = '.         .';
$strOptionally = '';
$strOr = '';
$strOverhead = ' ';
$strOverwriteExisting = '   ';

$strPageNumber = '  :';
$strPaperSize = '  ';
$strPartialText = ' ';
$strPasswordChanged = '  %s   .';
$strPasswordEmpty = '  !';
$strPasswordNotSame = '   !';
$strPassword = '';
$strPdfDbSchema = '     "%s" -  %s';
$strPdfInvalidTblName = ' "%s"  !';
$strPdfNoTables = ' ';
$strPerHour = ' ';
$strPerMinute = ' ';
$strPerSecond = ' ';
$strPersian = '';
$strPhoneBook = ' ';
$strPHP40203 = '  PHP 4.2.3,      -  (mbstring).    PHP  19404.         PHP  phpMyAdmin.';
$strPhp = '  PHP ';
$strPHPVersion = '  PHP';
$strPmaDocumentation = 'phpMyAdmin ';
$strPmaUriError = ' <tt>$cfg[\'PmaAbsoluteUri\']</tt>        !';
$strPolish = '';
$strPortrait = '';
$strPos1 = '';
$strPrevious = '';
$strPrimaryKeyHasBeenDropped = '    .';
$strPrimaryKeyName = '      ... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b></b>     <b>  </b>  !)';
$strPrimary = 'PRIMARY';
$strPrint = '';
$strPrintView = '  ';
$strPrintViewFull = '   (  )';
$strPrivDescAllPrivileges = '    GRANT.';
$strPrivDescAlter = '      .';
$strPrivDescCreateDb = '        .';
$strPrivDescCreateTbl = '    .';
$strPrivDescCreateTmpTable = '    .';
$strPrivDescDelete = '   .';
$strPrivDescDropDb = '       .';
$strPrivDescDropTbl = '   .';
$strPrivDescExecute = '    ;       MySQL.';
$strPrivDescFile = '          .';
$strPrivDescGrant = '           .';
$strPrivDescIndex = '     .';
$strPrivDescInsert = '     .';
$strPrivDescLockTables = '      .';
$strPrivDescMaxConnections = '    ,       .';
$strPrivDescMaxQuestions = '   ,         .';
$strPrivDescMaxUpdates = '   ,        ,        .';
$strPrivDescProcess3 = '      .';
$strPrivDescProcess4 = '        .';
$strPrivDescReferences = '      MySQL.';
$strPrivDescReload = '      (flashing)    .';
$strPrivDescReplClient = '        slaves / masters.';
$strPrivDescReplSlave = '  replication slaves.';
$strPrivDescSelect = '   .';
$strPrivDescShowDb = '       .';
$strPrivDescShutdown = '   .';
$strPrivDescSuper = ' ,        ;      ,            .';
$strPrivDescUpdate = '   .';
$strPrivDescUsage = ' .';
$strPrivileges = '';
$strPrivilegesReloaded = '   .';
$strProcesslist = '  ';
$strPutColNames = '      ';

$strQBEDel = '';
$strQBEIns = '';
$strQBE = '  ';
$strQueryFrame = '  ';
$strQueryOnDb = 'SQL-     <b>%s</b>:';
$strQuerySQLHistory = 'SQL-';
$strQueryStatistics = '<b>  </b>:    , %s     .';
$strQueryTime = '  %01.4f ';
$strQueryType = '  ';
$strQueryWindowLock = '      ';

$strReceived = '';
$strRecords = '';
$strReferentialIntegrity = '    ';
$strRefresh = '';
$strRelationalSchema = ' ';
$strRelationNotWorking = '      (linked)   .      %s%s.';
$strRelations = '';
$strRelationsForTable = '  ';
$strRelationView = '  ';
$strReloadFailed = '     MySQL.';
$strReloadingThePrivileges = '  ';
$strReloadMySQL = '  MySQL';
$strRemoveSelectedUsers = '   ';
$strRenameDatabaseOK = '  %s    %s';
$strRenameTable = '   ';
$strRenameTableOK = ' %s    %s';
$strRepairTable = '  ';
$strReplaceNULLBy = ' NULL ';
$strReplace = '';
$strReplaceTable = '       ';
$strReset = '';
$strResourceLimits = ' ';
$strReType = '';
$strRevokeAndDeleteDescr = '     USAGE      .';
$strRevokeAndDelete = '          .';
$strRevokeMessage = '    %s';
$strRevoke = '';
$strRomanian = '';
$strRowLength = '  ';
$strRows = '';
$strRowsFrom = '  ';
$strRowSize = '    ';
$strRowsModeFlippedHorizontal = ' ( )';
$strRowsModeHorizontal = '';
$strRowsModeOptions = ' %s          %s<br />';
$strRowsModeVertical = '';
$strRowsStatistic = '  ';
$strRunning = '  %s';
$strRunQuery = ' ';
$strRunSQLQuery = ' SQL /     %s';
$strRussian = '';

$strSaveOnServer = '     %s';
$strSave = '';
$strScaleFactorSmall = '           ';
$strSearchFormTitle = '    ';
$strSearchInTables = ' :';
$strSearchNeedle = '     (  : "%"):';
$strSearch = '';
$strSearchOption1 = '   ';
$strSearchOption2 = ' ';
$strSearchOption3 = ' ';
$strSearchOption4 = '  ';
$strSearchResultsFor = '    "<i>%s</i>" %s:';
$strSearchType = ':';
$strSecretRequired = '       (blowfish_secret).';
$strSelectADb = '    ';
$strSelectAll = '  ';
$strSelectFields = '  ( ):';
$strSelectNumRows = ' ';
$strSelectTables = ' ';
$strSend = '';
$strSent = '';
$strServerChoice = '  ';
$strServer = '';
$strServerNotResponding = '   ';
$strServerStatus = '    MySQL ';
$strServerStatusUptime = ' MySQL    %s.    %s.';
$strServerTabProcesslist = '';
$strServerTabVariables = '';
$strServerTrafficNotes = '<b>  </b>:         MySQL     .';
$strServerVars = '   ';
$strServerVersion = '  ';
$strSessionValue = ' ';
$strSetEnumVal = '     "enum"  "set",      : \'a\',\'b\',\'c\'...<br />       ("\")   ("\'")   ,      (:  \'\\\\xyz\'  \'a\\\'b\').';
$strShowAll = ' ';
$strShowColor = ' ';
$strShowDatadictAs = '    ';
$strShowFullQueries = '   ';
$strShowGrid = ' ';
$strShowingRecords = '   ';
$strShowPHPInfo = '  PHP ';
$strShowTableDimension = '   ';
$strShowTables = ' ';
$strShowThisQuery = '    ';
$strShow = '';
$strSimplifiedChinese = ' ';
$strSingly = '()';
$strSize = '';
$strSlovak = '';
$strSlovenian = '';
$strSortByKey = '  ';
$strSort = '';
$strSpaceUsage = ' ';
$strSpanish = '';
$strSplitWordsWithSpace = '       (" ").';
$strSQLExportCompatibility = '   SQL';
$strSQLExportType = '  ';
$strSQLOptions = '   SQL';
$strSQLParserBugMessage = '        SQL .   -,     .        ,           .                MySQL.    MySQL  -,   ,         .                  ,    SQL     ,           CUT  -:';
$strSQLParserUserError = ',     SQL  .    MySQL   ,   ,         ';
$strSQLQuery = 'SQL ';
$strSQLResult = 'SQL ';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = ' ';
$strSQPBugUnclosedQuote = ' ';
$strSQPBugUnknownPunctuation = '   ';
$strStatCheckTime = ' ';
$strStatCreateTime = '  ';
$strStatement = '';
$strStatUpdateTime = ' ';
$strStatus = '';
$strStorageEngine = '  ';
$strStorageEngines = '  ';
$strStrucCSV = 'CSV ';
$strStrucData = '  ';
$strStrucDrop = '  \'DROP TABLE\'';
$strStrucExcelCSV = 'CSV  MS Excel ';
$strStrucOnly = ' ';
$strStructPropose = '  ';
$strStructure = '';
$strSubmit = '';
$strSuccess = 'SQL    ';
$strSum = '';
$strSwedish = '';
$strSwitchToTable = '   ';

$strTableComments = '  ';
$strTableEmpty = '    !';
$strTableHasBeenDropped = ' %s  ';
$strTableHasBeenEmptied = ' %s  ';
$strTableHasBeenFlushed = '   %s  ';
$strTableMaintenance = '  ';
$strTableOfContents = '';
$strTableOptions = '  ';
$strTables = '%s ()';
$strTableStructure = '  ';
$strTableType = '  ';
$strTable = ' ';
$strTblPrivileges = '   ';
$strTextAreaLength = '   ,<br />        ';
$strThai = '';
$strTheContent = '    .';
$strTheContents = '              .';
$strTheme = ' / ';
$strTheTerminator = '    .';
$strThisHost = ' ';
$strThisNotDirectory = '   ';
$strThreadSuccessfullyKilled = ' %s   .';
$strTime = '';
$strTotal = '';
$strTotalUC = '';
$strTraditionalChinese = ' ';
$strTraditionalSpanish = ' ';
$strTraffic = '';
$strTransformation_application_octetstream__download = '        .        .              .    ,          .';
$strTransformation_image_jpeg__inline = ' thumbnail; : ,    (  )';
$strTransformation_image_jpeg__link = '     (  , i.e.).';
$strTransformation_image_png__inline = ' image/jpeg: inline';
$strTransformation_text_plain__dateformat = '  TIME, TIMESTAMP  DATETIME         .     ( )       ( : 0).               PHP - strftime().';
$strTransformation_text_plain__external = '  :           .     .    Tidy,    HTML .    ,      libraries/transformations/text_plain__external.inc.php           .                   .       1,     htmlspecialchars() (   1).       1,   NOWRAP    ,          (   1)';
$strTransformation_text_plain__formatted = '    .';
$strTransformation_text_plain__imagelink = '        ;      "http://domain.com/",      ,   .';
$strTransformation_text_plain__link = '      ;      "http://domain.com/",      .';
$strTransformation_text_plain__substr = '   .            (   0).        .   ,     .         ( : ...) .';
$strTruncateQueries = '   ';
$strTurkish = '';
$strType = '';

$strUkrainian = '';
$strUncheckAll = '  ';
$strUnicode = 'Unicode';
$strUnique = '';
$strUnknown = '';
$strUnselectAll = '  ';
$strUpdatePrivMessage = '    %s.';
$strUpdateProfileMessage = '  .';
$strUpdateQuery = ' ';
$strUpdComTab = '           Column_comments ';
$strUpgrade = '    %s %s  -.';
$strUsage = '';
$strUseBackquotes = '         ';
$strUseHostTable = '  Host';
$strUserAlreadyExists = ' %s  !';
$strUserEmpty = '   !';
$strUserName = ' ';
$strUserNotFound = '        .';
$strUserOverview = '  ';
$strUsersDeleted = '    .';
$strUsersHavingAccessToDb = '     &quot;%s&quot;';
$strUser = '';
$strUseTables = ' ';
$strUseTextField = '  ';
$strUseThisValue = '  ';

$strValidateSQL = ' SQL-';
$strValidatorError = 'SQL      .       PHP ,      %s%s.';
$strValue = '';
$strVar = '';
$strViewDumpDatabases = '      ';
$strViewDumpDB = '  ';
$strViewDump = '  ';
$strViewHasBeenDropped = ' %s  ';

$strWebServerUploadDirectoryError = '     upload     ';
$strWebServerUploadDirectory = '  upload   ';
$strWelcome = '   %s';
$strWestEuropean = '-';
$strWildcard = '  ';
$strWindowNotFound = '       .                        ';
$strWithChecked = '  :';
$strWritingCommentNotPossible = '     ';
$strWritingRelationNotPossible = '     ';
$strWrongUser = ' /.  .';

$strXML = 'XML';

$strYes = '';

$strZeroRemovesTheLimit = ':      0 ()  .';
$strZip = '"zip-"';

// To translate:
$strAndThen = 'and then';  //to translate

$strBinaryLog = 'Binary log';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBusyPages = 'Busy pages';  //to translate

$strCheckOverhead = 'Check tables with overhead';  //to translate
$strCopy = 'Copy';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate

$strDataPages = 'Pages containing data';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate

$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate

$strFreePages = 'Free pages';  //to translate

$strGenerate = 'Generate';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate

$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate

$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate

$strLatchedPages = 'Latched pages';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate

$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate

$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate

$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate

$strReadRequests = 'Read requests';  //to translate
$strRoutines = 'Routines';  //to translate

$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate

$strTakeIt = 'take it';  //to translate
$strToggleScratchboard = 'toggle scratchboard';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate

$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate

$strVersionInformation = 'Version information';  //to translate
$strView = 'View';  //to translate

$strWriteRequests = 'Write requests';  //to translate

?>
